@@ -31,9 +31,16 @@
 #endif
 
 #include "common.h"
-#include "gui.h"
 #include "sio.h"
 
+#ifdef MAEMO_CHANGES
+# include "maemo/gui.h"
+#endif
+
+extern "C" {
+s8* newpackfile = NULL;
+}
+
 int psx4all_emulating=0;
 s8 iphonefile[256];
 s8 svsfilename[260];
@@ -134,6 +141,7 @@ void sort_dir(struct dir_item *list, int num_items, int sepdir) {
 	}
 }
 
+#ifndef MAEMO_CHANGES
 static s8 filereq_fullgamepath[257];
 static struct dir_item filereq_dir_items[1024] = {{0,0},};
 
@@ -391,6 +399,7 @@ char *FileReq(char *dir, const char *ext)
 
 	return NULL;
 }
+#endif // MAEMO_CHANGES
 
 s32 SelectGame()
 {
@@ -399,12 +408,11 @@ s32 SelectGame()
 
 	s32 menu_state = 0;
 	s32 menu_pos = 0;
-	s8* newpackfile = NULL;
 
+#ifndef MAEMO_CHANGES
 	gp2x_video_RGB_clearscreen16();
 	gp2x_video_flip();
 
-#if 1
 	// pick a game
 	for(;;)
 	{
@@ -837,11 +845,14 @@ s32 SelectGame()
 		}
 	}
 #else
+#ifndef MAEMO_CHANGES
 	//newpackfile = "Einhander.bin";
 	//newpackfile = "Einhander.cbn";
 	Config.HLE = 1;
 	//newpackfile = "Cotton Jap.bin";
-	newpackfile = "Cotton Jap.cbn";
+	//newpackfile = "Cotton Jap.cbn";
+	newpackfile = "Tekken3.iso";
+#endif // MAEMO_CHANGES
 #endif
 	DEBUGF("loaded %s", newpackfile);
 	packfile = newpackfile;
@@ -959,6 +970,9 @@ int main(int argc, char *argv[])
 		strncpy(gamepath,argv[1],256);
 #else
 	strncpy(gamepath,ROM_PREFIX,256);
+#ifdef MAEMO_CHANGES
+	gui_init(&argc, &argv);
+#endif // MAEMO_CHANGES
 #endif
 #endif
 #endif
@@ -1000,7 +1014,7 @@ int main(int argc, char *argv[])
 	Config.VSyncWA = 0;
 
 #ifdef DATA_PREFIX
-	sprintf(Config.BiosDir, "%s", DATA_PREFIX);
+	sprintf(Config.BiosDir, "%s", gamepath);
 	sprintf(Config.Bios, "/scph1001.bin");
 	sprintf(Config.Mcd1, "%s/mcd001.mcr", DATA_PREFIX);
 	sprintf(Config.Mcd2, "%s/mcd002.mcr", DATA_PREFIX);
@@ -1018,6 +1032,11 @@ int main(int argc, char *argv[])
 #endif
 #endif
 
+#ifdef MAEMO_CHANGES
+	gui_select_game();
+	if (newpackfile == NULL)
+		exit(1);
+#endif // MAEMO_CHANGES
 	gp2x_init(1000, 16, 11025, 16, 1, 60, 1);
 #ifndef GP2X
 	gp2x_video_flip_single();
